==> alfresco-remote-api-16.36-sources.jar: org/alfresco/opencmis/BaseUrlGenerator.java <==
/*
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.opencmis;

import javax.servlet.http.HttpServletRequest;

import org.alfresco.opencmis.CMISDispatcherRegistry.Binding;

/**
 * Generates an OpenCMIS base url based on the request, repository id and binding.
 * 
 * @author steveglover
 *
 */
public interface BaseUrlGenerator
{
	String getContextPath(HttpServletRequest httpReq);
	String getServletPath(HttpServletRequest req);
	String getBaseUrl(HttpServletRequest req, String repositoryId, Binding binding);
	String getRequestURI(HttpServletRequest req, String repositoryId, String operation, String id);
}

==> alfresco-remote-api-23.6.0.32-sources.jar: org/alfresco/opencmis/BaseUrlGenerator.java <==
/*
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2023 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.opencmis;

import jakarta.servlet.http.HttpServletRequest;

import org.alfresco.opencmis.CMISDispatcherRegistry.Binding;

/**
 * Generates an OpenCMIS base url based on the request, repository id and binding.
 * 
 * @author steveglover
 *
 */
public interface BaseUrlGenerator
{
	String getContextPath(HttpServletRequest httpReq);
	String getServletPath(HttpServletRequest req);
	String getBaseUrl(HttpServletRequest req, String repositoryId, Binding binding);
	String getRequestURI(HttpServletRequest req, String repositoryId, String operation, String id);
}
